/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Adolf-Dambach-Strae
 * 76571 Gaggenau
 * Phone: +49-7225-64-01
 * Fax: +49-7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.lkwueberholverbotbelastungwochentag;

import de.bsvrz.dav.daf.main.ClientDavConnection;
import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Diese Klasse speichert die Daten der Attributgruppe !atg.sswSbaUeLkwberholverbotBelastungWochentag!.<p>
 * 
 * ber Getter und Setter kann auf die Daten zugegriffen werden.
 *
 * @version $Revision: 1.1 $ / $Date: 2015/08/26 13:34:53 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class ParameterLkwUeberholverbotBelastungWochentag
{
	/**
	 * Pid der Attributgruppe.
	 */
	private String m_pidAtg = "atg.sswSbaUeLkwberholverbotBelastungWochentag";

	/**
	 * Parameterversorgung fr 2 Fahrstreifen.
	 */
	public ParameterLkwUeberholverbotBelastungWochentagFahrstreifen m_fahrstreifen2;

	/**
	 * Parameterversorgung fr 3 Fahrstreifen.
	 */
	public ParameterLkwUeberholverbotBelastungWochentagFahrstreifen m_fahrstreifen3;

	/**
	 * Parameterversorgung fr 4 Fahrstreifen.
	 */
	public ParameterLkwUeberholverbotBelastungWochentagFahrstreifen m_fahrstreifen4;
	/**
	 * Referenz auf einen EreinisTyp.
	 */
	private SystemObject m_ereignisTyp;
	
	/**
	 * Default-Konstruktor ohne weitere Funktion.
	 */
	public ParameterLkwUeberholverbotBelastungWochentag()
	{
	}
	/**
	 * Konstruktor mit bernahme des bergebenen Datensatzes in die interne Struktur.
	 *  
	 * @param rdata Datensatz der Parameter.
	 */
	public ParameterLkwUeberholverbotBelastungWochentag(ResultData rdata)
	{
		setdaten(rdata);
	}
	
	/**
	 * bernahme des bergebenen Datensatzes in die interne Struktur.
	 * 
	 * @param rdata Datensatz der Parameter.
	 */
	public void setdaten(ResultData rdata)
	{
		if (rdata != null)
		{
			Data data = rdata.getData();
			if (data != null)
			{
				if (m_fahrstreifen2 == null)
					m_fahrstreifen2 = new ParameterLkwUeberholverbotBelastungWochentagFahrstreifen();

				m_fahrstreifen2.setQUevEin(data.getItem("2Fahrstreifen").getUnscaledValue("QBvPEin").intValue());
				m_fahrstreifen2.setQUevAus(data.getItem("2Fahrstreifen").getUnscaledValue("QBvPAus").intValue());
				m_fahrstreifen2.setAUevEin(data.getItem("2Fahrstreifen").getUnscaledValue("QLkwPEin").intValue());
				m_fahrstreifen2.setAUevAus(data.getItem("2Fahrstreifen").getUnscaledValue("QLkwPAus").intValue());

				if (m_fahrstreifen3 == null)
					m_fahrstreifen3 = new ParameterLkwUeberholverbotBelastungWochentagFahrstreifen();

				m_fahrstreifen3.setQUevEin(data.getItem("3Fahrstreifen").getUnscaledValue("QBvPEin").intValue());
				m_fahrstreifen3.setQUevAus(data.getItem("3Fahrstreifen").getUnscaledValue("QBvPAus").intValue());
				m_fahrstreifen3.setAUevEin(data.getItem("3Fahrstreifen").getUnscaledValue("QLkwPEin").intValue());
				m_fahrstreifen3.setAUevAus(data.getItem("3Fahrstreifen").getUnscaledValue("QLkwPAus").intValue());

				if (m_fahrstreifen4 == null)
					m_fahrstreifen4 = new ParameterLkwUeberholverbotBelastungWochentagFahrstreifen();

				m_fahrstreifen4.setQUevEin(data.getItem("4Fahrstreifen").getUnscaledValue("QBvPEin").intValue());
				m_fahrstreifen4.setQUevAus(data.getItem("4Fahrstreifen").getUnscaledValue("QBvPAus").intValue());
				m_fahrstreifen4.setAUevEin(data.getItem("4Fahrstreifen").getUnscaledValue("QLkwPEin").intValue());
				m_fahrstreifen4.setAUevAus(data.getItem("4Fahrstreifen").getUnscaledValue("QLkwPAus").intValue());				
			
				m_ereignisTyp = data.getReferenceValue("keinLkwFreierTag").getSystemObject();
			}
			else
			{
				m_fahrstreifen2 = new ParameterLkwUeberholverbotBelastungWochentagFahrstreifen();
				m_fahrstreifen3 = new ParameterLkwUeberholverbotBelastungWochentagFahrstreifen();
				m_fahrstreifen4 = new ParameterLkwUeberholverbotBelastungWochentagFahrstreifen();				
				
				m_ereignisTyp = null;
			}
		}		
	}

	/**
	 * Erzeugt einen Datensatz der Attributgruppe <code>atg.sswSbaUeLkwberholverbotBelastung</code> mit
	 * den Daten der internen Struktur.
	 * 
	 * @param connection Aktuelle Verbindung zum Datenverteiler.
	 * @return erzeugter Datensatz.
	 */
	public Data erzeugeDatensatz(ClientDavConnection connection)
	{
		DataModel dm = connection.getDataModel();		
		Data dataNeu = connection.createData(dm.getAttributeGroup(m_pidAtg));

		if (dataNeu != null)
		{
			dataNeu.getItem("2Fahrstreifen").getUnscaledValue("QBvPEin").set(m_fahrstreifen2.getQBUevPEin());
			dataNeu.getItem("2Fahrstreifen").getUnscaledValue("QBvPAus").set(m_fahrstreifen2.getQBUevPAus());
			dataNeu.getItem("2Fahrstreifen").getUnscaledValue("QLkwPEin").set(m_fahrstreifen2.getQLkwPEin());
			dataNeu.getItem("2Fahrstreifen").getUnscaledValue("QLkwPAus").set(m_fahrstreifen2.getQLkwPAus());

			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("QBvPEin").set(m_fahrstreifen3.getQBUevPEin());
			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("QBvPAus").set(m_fahrstreifen3.getQBUevPAus());
			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("QLkwPEin").set(m_fahrstreifen3.getQLkwPEin());
			dataNeu.getItem("3Fahrstreifen").getUnscaledValue("QLkwPAus").set(m_fahrstreifen3.getQLkwPAus());

			dataNeu.getItem("4Fahrstreifen").getUnscaledValue("QBvPEin").set(m_fahrstreifen4.getQBUevPEin());
			dataNeu.getItem("4Fahrstreifen").getUnscaledValue("QBvPAus").set(m_fahrstreifen4.getQBUevPAus());
			dataNeu.getItem("4Fahrstreifen").getUnscaledValue("QLkwPEin").set(m_fahrstreifen4.getQLkwPEin());
			dataNeu.getItem("4Fahrstreifen").getUnscaledValue("QLkwPAus").set(m_fahrstreifen4.getQLkwPAus());

			if (m_ereignisTyp != null)
				dataNeu.getReferenceValue("keinLkwFreierTag").setSystemObject(m_ereignisTyp);
			else
				dataNeu.getReferenceValue("keinLkwFreierTag").setText("undefiniert");
				
			return dataNeu;
		}
		
		return null;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() 
	{
		StringBuffer string = new StringBuffer();
		
		string.append("\n 2 Fahrstreifen " + m_fahrstreifen2 +
				          "\n 3 Fahrstreifen " + m_fahrstreifen3 +
				          "\n 4 Fahrstreifen " + m_fahrstreifen4 +
				          "\n EreignisTyp    " + m_ereignisTyp);
		
		return string.toString();
  }

	/**
	 * Gibt fr die bergebene Anzahl Fahrstreifen den entsprechenden Datensatz zurck.
	 * 
	 * @param anzFs Anzahl der Fahrstreifen.
	 * @return Parameterversorgung der bergebenen Anzahl von Fahrstreifen.
	 */
	public ParameterLkwUeberholverbotBelastungWochentagFahrstreifen getParameterFahrstreifen(int anzFs)
	{
		switch (anzFs)
		{
			case 0:
			case 1:
			{				
				return null;
			}
			case 2:
			{				
				return m_fahrstreifen2;
			}
			case 3:
			{				
				return m_fahrstreifen3;
			}
		}
		
		return m_fahrstreifen4;
	}

	/**
	 * bernimmt die bergebenen Grenzwerte in die interne Struktur der parameter fr Fahrstreifen 2.
	 * 
	 * @param qUevEin Grenzwert Einschaltkriterium QB Prognose. 
	 * @param qUevAus Grenzwert Ausschaltkriterium QB Prognose.
	 * @param aUevEin Grenzwert Einschaltkriterium Lkw-Anteil in Prozent.
	 * @param aUevAus Grenzwert Ausschaltkriterium Lkw-Anteil in Prozent.
	 */
	public void setWerteFahrstreifen2(int qUevEin, int qUevAus, int aUevEin, int aUevAus)
	{
		if (m_fahrstreifen2 == null)
			m_fahrstreifen2 = new ParameterLkwUeberholverbotBelastungWochentagFahrstreifen();
		
		m_fahrstreifen2.setQUevEin(qUevEin);
		m_fahrstreifen2.setQUevAus(qUevAus);
		m_fahrstreifen2.setAUevEin(aUevEin);		
		m_fahrstreifen2.setAUevAus(aUevAus);
	}

	/**
	 * bernimmt die bergebenen Grenzwerte in die interne Struktur der parameter fr Fahrstreifen 3.
	 * 
	 * @param qUevEin Grenzwert Einschaltkriterium QB Prognose. 
	 * @param qUevAus Grenzwert Ausschaltkriterium QB Prognose.
	 * @param aUevEin Grenzwert Einschaltkriterium Lkw-Anteil in Prozent.
	 * @param aUevAus Grenzwert Ausschaltkriterium Lkw-Anteil in Prozent.
	 */
	public void setWerteFahrstreifen3(int qUevEin, int qUevAus, int aUevEin, int aUevAus)
	{
		if (m_fahrstreifen3 == null)
			m_fahrstreifen3 = new ParameterLkwUeberholverbotBelastungWochentagFahrstreifen();
		
		m_fahrstreifen3.setQUevEin(qUevEin);
		m_fahrstreifen3.setQUevAus(qUevAus);
		m_fahrstreifen3.setAUevEin(aUevEin);		
		m_fahrstreifen3.setAUevAus(aUevAus);
	}

	/**
	 * bernimmt die bergebenen Grenzwerte in die interne Struktur der parameter fr Fahrstreifen 4.
	 * 
	 * @param qUevEin Grenzwert Einschaltkriterium QB Prognose. 
	 * @param qUevAus Grenzwert Ausschaltkriterium QB Prognose.
	 * @param aUevEin Grenzwert Einschaltkriterium Lkw-Anteil in Prozent.
	 * @param aUevAus Grenzwert Ausschaltkriterium Lkw-Anteil in Prozent.
	 */
	public void setWerteFahrstreifen4(int qUevEin, int qUevAus, int aUevEin, int aUevAus)
	{
		if (m_fahrstreifen4 == null)
			m_fahrstreifen4 = new ParameterLkwUeberholverbotBelastungWochentagFahrstreifen();
		
		m_fahrstreifen4.setQUevEin(qUevEin);
		m_fahrstreifen4.setQUevAus(qUevAus);
		m_fahrstreifen4.setAUevEin(aUevEin);		
		m_fahrstreifen4.setAUevAus(aUevAus);
	}

	/**
	 * Gibt die Parameterversorgung fr 2 Fahrstreifen zurck.
	 * 
	 * @return Parameterversorgung fr 2 Fahrstreifen.
	 */
	public ParameterLkwUeberholverbotBelastungWochentagFahrstreifen getFahrstreifen2()
	{
		return m_fahrstreifen2;
	}

	/**
	 * Setzt die Parameterversorgung fr 2 Fahrstreifen.
	 * 
	 * @param fahrstreifen2 zu setzende Parameterversorgung fr 2 Fahrstreifen.
	 */
	public void setFahrstreifen2(ParameterLkwUeberholverbotBelastungWochentagFahrstreifen fahrstreifen2)
	{
		m_fahrstreifen2 = fahrstreifen2;
	}

	/**
	 * Gibt die Parameterversorgung fr 3 Fahrstreifen zurck.
	 * 
	 * @return Parameterversorgung fr 3 Fahrstreifen.
	 */
	public ParameterLkwUeberholverbotBelastungWochentagFahrstreifen getFahrstreifen3()
	{
		return m_fahrstreifen3;
	}

	/**
	 * Setzt die Parameterversorgung fr 3 Fahrstreifen.
	 * 
	 * @param fahrstreifen3 zu setzende Parameterversorgung fr 3 Fahrstreifen.
	 */
	public void setFahrstreifen3(ParameterLkwUeberholverbotBelastungWochentagFahrstreifen fahrstreifen3)
	{
		m_fahrstreifen3 = fahrstreifen3;
	}

	/**
	 * Gibt die Parameterversorgung fr 4 Fahrstreifen zurck.
	 * 
	 * @return Parameterversorgung fr 4 Fahrstreifen.
	 */
	public ParameterLkwUeberholverbotBelastungWochentagFahrstreifen getFahrstreifen4()
	{
		return m_fahrstreifen4;
	}

	/**
	 * Setzt die Parameterversorgung fr 4 Fahrstreifen.
	 * 
	 * @param fahrstreifen4 zu setzende Parameterversorgung fr 4 Fahrstreifen.
	 */
	public void setFahrstreifen4(ParameterLkwUeberholverbotBelastungWochentagFahrstreifen fahrstreifen4)
	{
		m_fahrstreifen4 = fahrstreifen4;
	}

	/**
	 * Gibt den Wert der Variable m_ereignisTyp zurck.
	 *
	 * @return Wert der Variable m_ereignisTyp.
	 */
	public SystemObject getEreignisTyp()
	{
		return m_ereignisTyp;
	}
	/**
	 * Setzt den Wert der Variable m_ereignisTyp.
	 *
	 * @param ereignisTyp zu setzender Wert der Variable m_ereignisTyp.
	 */
	public void setEreignisTyp(SystemObject ereignisTyp)
	{
		m_ereignisTyp = ereignisTyp;
	}
	
  /**
	 * Innere Klasse zum Speichern der Parameter pro Fahrstreifen.<p>
	 * ber Getter und Setter kann auf die Daten zugegriffen werden.
	 * 
   * @version $Revision: 1.1 $ / $Date: 2015/08/26 13:34:53 $ / ($Author: Asal $)
	 * @author  Swarco Traffic Systems GmbH
	 * @author  Matthias Obert
	 */
  public class ParameterLkwUeberholverbotBelastungWochentagFahrstreifen
  {
  	/**
  	 * Grenzwert Einschaltkriterium QB Prognose in PkwE/h.
   	 */
  	protected int  m_qbUevPEin;
  	/**
  	 * Grenzwert Ausschaltkriterium QB Prognose in PkwE/h.
   	 */
  	protected int  m_qbUevPAus;
  	/**
  	 * Grenzwert Einschaltkriterium QLkw in Fz/h.
  	 */
  	protected int  m_qLkwPEin;
  	/**
  	 * Grenzwert Ausschaltkriterium QLkw in Fz/h.
  	 */
  	protected int  m_qLkwPAus;

  
		/**
		 * Default-Konstruktor ohne weitere Funktion.
		 */
  	public ParameterLkwUeberholverbotBelastungWochentagFahrstreifen()
		{
		}

  	/* (non-Javadoc)
		 * @see java.lang.Object#toString()
		 */
		@Override
		public String toString() 
		{
			StringBuffer string = new StringBuffer();
			
			string.append(" QBvPEin " + m_qbUevPEin +
					          " QBvPAus " + m_qbUevPAus +
					          " QLkwPEin " + m_qLkwPEin +
					          " QLkwPAus " + m_qLkwPAus);
			
			return string.toString();
	  }

		/**
		 * Gibt den Grenzwert Einschaltkriterium QB Prognose in PkwE/h zurck.
		 * 
		 * @return Grenzwert Einschaltkriterium QB Prognose in PkwE/h.
		 */
		public int getQBUevPEin()
		{
			return m_qbUevPEin;
		}

		/**
		 * Setz den Grenzwert Einschaltkriterium QB Prognose in PkwE/h.
		 * 
		 * @param uevEin zu setzender Grenzwert Einschaltkriterium QB Prognose in PkwE/h.
		 */
		public void setQUevEin(int uevEin)
		{
			m_qbUevPEin = uevEin;
		}

		/**
		 * Gibt den Grenzwert Ausschaltkriterium QB Prognose in PkwE/h zurck.
		 * 
		 * @return Grenzwert Ausschaltkriterium QB Prognose in PkwE/h.
		 */
		public int getQBUevPAus()
		{
			return m_qbUevPAus;
		}

		/**
		 * Setzt den Grenzwert Ausschaltkriterium QB Prognose in PkwE/h.
		 * 
		 * @param uevAus zu setzender Grenzwert Ausschaltkriterium QB Prognose in PkwE/h.
		 */
		public void setQUevAus(int uevAus)
		{
			m_qbUevPAus = uevAus;
		}

		/**
		 * Gibt den Grenzwert Einschaltkriterium QLkw in Fz/h zurck
		 * .
		 * @return Grenzwert Einschaltkriterium QLkw in Fz/h.
		 */
		public int getQLkwPEin()
		{
			return m_qLkwPEin;
		}

		/**
		 * Setzt den Grenzwert Einschaltkriterium Lkw-Anteil in Prozent.
		 * 
		 * @param uevEin zu setzender Grenzwert Einschaltkriterium Lkw-Anteil in Prozent.
		 */
		public void setAUevEin(int uevEin)
		{
			m_qLkwPEin = uevEin;
		}

		/**
		 * Gibt den Grenzwert Ausschaltkriterium QLkw in Fz/h zurck
		 * .
		 * @return Grenzwert Ausschaltkriterium QLkw in Fz/h.
		 */
		public int getQLkwPAus()
		{
			return m_qLkwPAus;
		}

		/**
		 * Setzt den Grenzwert Ausschaltkriterium Lkw-Anteil in Prozent.
		 * 
		 * @param uevAus zu setzender Grenzwert Ausschaltkriterium Lkw-Anteil in Prozent.
		 */
		public void setAUevAus(int uevAus)
		{
			m_qLkwPAus = uevAus;
		}
  }

}